@@ -29,7 +29,7 @@ class Env:
     firefly_url_lab = os.environ.get(ENV_FF_URL_LAB)
     firefly_url = os.environ.get(ENV_FF_URL)
     firefly_channel_from_env = os.environ.get(ENV_FF_CHANNEL)
-    firefly_html = os.environ.get(ENV_FF_HTML, 'slate.html')
+    firefly_html = os.environ.get(ENV_FF_HTML, '')
     user = os.environ.get(ENV_USER, '')
 
     @classmethod
@@ -46,7 +46,7 @@ class Env:
         if not cls.firefly_channel_lab:
             raise RuntimeError(COULD_NO_FIND_ENV + ENV_FF_CHANNEL_LAB + '. ' + EXT_INCORRECT + ' ' + SUGGESTION)
         if not cls.firefly_url_lab:
-            raise RuntimeError(COULD_NO_FIND_ENV + ENV_FF_URL_LAB_LAB + '. ' + EXT_INCORRECT + ' ' + SUGGESTION)
+            raise RuntimeError(COULD_NO_FIND_ENV + ENV_FF_URL_LAB + '. ' + EXT_INCORRECT + ' ' + SUGGESTION)
 
     @classmethod
     def show_start_browser_tab_msg(cls, url):
@@ -93,12 +93,20 @@ class Env:
 
     @classmethod
     def failed_net_message(cls, location, status_code=-1):
-        s_str = 'with status: %s' % status_code if (status_code > -1) else ''
-        check = 'You may want to check the URL with your web browser.\n'
-        err_message = 'Connection fail to URL %s %s\n%s' % (location, s_str, check)
-        if cls.firefly_lab_extension and cls.firefly_url_lab:
-            err_message += ('\nCheck the Firefly URL in ~/.jupyter/jupyter_notebook_config.py' +
-                            ' or ~/.jupyter/jupyter_notebook_config.json')
-        elif firefly_url:
-            err_message += 'Check setting of FIREFLY_URL environment variable: %s' % cls.firefly_url
+        status_str = f'with status: {status_code}' if status_code > -1 else ''
+        check_msg = 'You may want to check the URL with your web browser.\n'
+        err_message = f'Connection failed to URL {location} {status_str}\n{check_msg}'
+        
+        # url sources in order of precedence
+        url_sources = []
+        if cls.firefly_url: # any environment
+            url_sources.append(f'environment variable "{ENV_FF_URL}"')
+        if cls.firefly_lab_extension and cls.firefly_url_lab: # lab environment
+            url_sources += [
+                '~/.jupyter/jupyter_notebook_config.json',
+                '~/.jupyter/jupyter_notebook_config.py',
+            ]
+        url_sources_msg = f', or is set via {" or ".join(url_sources)}' if url_sources else ''
+        err_message += (f'\nCheck if the Firefly URL is correct, which is '
+                        f'passed as a parameter{url_sources_msg}.')
         return err_message
