@@ -64,17 +64,21 @@ def ensure3(val, name):
     return ret
 
 
-# actions from Firefly
 ACTION_DICT = {
-    'ShowFits': 'ImagePlotCntlr.PlotImage',
+    # actions from Firefly JS
+    'ShowImage': 'ImagePlotCntlr.PlotImage',
     'AddExtension': 'ExternalAccessCntlr/extensionAdd',
     'FetchTable': 'table.fetch',
     'ShowTable': 'table.search',
+    'TableFilter': 'table.filter',
+    'TableSort': 'table.sort',
     'ShowXYPlot': 'charts.data/chartAdd',
     'ShowPlot': 'charts.data/chartAdd',
     'ZoomImage': 'ImagePlotCntlr.ZoomImage',
     'PanImage': 'ImagePlotCntlr.recenter',
+    'AlignImages': 'ImagePlotCntlr.wcsMatch',
     'StretchImage': 'ImagePlotCntlr.StretchChange',
+    'ColorImage': 'ImagePlotCntlr.ColorChange',
     'CreateRegionLayer': 'DrawLayerCntlr.RegionPlot.createLayer',
     'DeleteRegionLayer': 'DrawLayerCntlr.RegionPlot.deleteLayer',
     'AddRegionData': 'DrawLayerCntlr.RegionPlot.addRegion',
@@ -82,12 +86,18 @@ ACTION_DICT = {
     'PlotMask': 'ImagePlotCntlr.plotMask',
     'DeleteOverlayMask': 'ImagePlotCntlr.deleteOverlayPlot',
     'AddCell': 'layout.addCell',
+    'SetLayoutMode': 'layout.setLayoutMode',
+    'UpdateLayout': 'layout.updateLayout',
+    'TriviewLayout': 'layout.triviewLayout',
     'ShowCoverage': 'layout.enableSpecialViewer',
     'ShowImageMetaData': 'layout.enableSpecialViewer',
     'ReinitViewer': 'app_data.reinitApp',
     'ShowHiPS': 'ImagePlotCntlr.PlotHiPS',
     'ShowImageOrHiPS': 'ImagePlotCntlr.plotHiPSOrImage',
     'ImagelineBasedFootprint': 'DrawLayerCntlr.ImageLineBasedFP.imagelineBasedFPCreate',
+    'ShowAnyData': 'app_data.externalUpload',
+
+    # actions from jupyter_firefly_extensions
     'StartLabWindow': 'StartLabWindow',
     'StartBrowserTab': 'StartBrowserTab'
 }
